@@ -1,6 +1,7 @@
 from .utils.signal import signal
 from .utils.runner import Runner
 from datetime import datetime
+from .cfg import l
 
 
 
@@ -51,8 +52,8 @@ def CHECK_POINT(desc:str, condition, failStop=True, LogSreenWebDriverIfFail = No
 
         # 记录下当前执行结果为失败
         Runner.curRunningCase.execRet='fail'
-        Runner.curRunningCase.error='检查点不通过'
-        Runner.curRunningCase.stacktrace="\n"*3+'具体错误看测试步骤检查点'
+        Runner.curRunningCase.error=('检查点不通过','checkpoint failed')[l.n]
+        Runner.curRunningCase.stacktrace="\n"*3+('具体错误看测试步骤检查点','see checkpoint of case for details')[l.n]
         # 如果失败停止，中止此测试用例
         if failStop:
             raise AssertionError()
